@@ -13,10 +13,10 @@ def scipy_optimize(model: Model, x0: np.ndarray = None,
     x0 = np.zeros(model.size) if x0 is None else x0
     bounds = model.uvec.T
     constraints = [LinearConstraint(
-        model.spline_umat,
-        model.spline_uvec[0],
-        model.spline_uvec[1]
-    )] if model.has_spline_uprior() else []
+        model.linear_umat,
+        model.linear_uvec[0],
+        model.linear_uvec[1]
+    )] if model.has_linear_uprior() else []
 
     result = minimize(model.objective, x0,
                       method="trust-constr",
